@@ -20,6 +20,7 @@ import uuid
 
 from cdpcli import credentials, DEFAULT_PROFILE_NAME
 from cdpcli import xform_name
+from cdpcli.auth import AccessTokenAuth
 from cdpcli.auth import Ed25519v1Auth
 from cdpcli.auth import RSAv1Auth
 from cdpcli.cdprequest import prepare_request_dict
@@ -60,13 +61,15 @@ class ClientCreator(object):
                       service_name,
                       endpoint_url,
                       tls_verification,
-                      credentials):
+                      credentials,
+                      client_config=None):
         service_model = self._load_service_model(service_name)
         cls = self._create_client_class(service_name, service_model)
         client_args = self._get_client_args(service_model,
                                             endpoint_url,
                                             tls_verification,
-                                            credentials)
+                                            credentials,
+                                            client_config)
         return cls(**client_args)
 
     def _load_service_model(self, service_name):
@@ -86,18 +89,30 @@ class ClientCreator(object):
                          service_model,
                          endpoint_url,
                          tls_verification,
-                         credentials):
+                         credentials,
+                         client_config):
         serializer = create_serializer()
-        timeout = (DEFAULT_TIMEOUT, DEFAULT_TIMEOUT)
+        if client_config is not None:
+            connect_timeout = client_config.connect_timeout
+            if connect_timeout <= 0:
+                connect_timeout = None
+            read_timeout = client_config.read_timeout
+            if read_timeout <= 0:
+                read_timeout = None
+        else:
+            connect_timeout = DEFAULT_TIMEOUT
+            read_timeout = DEFAULT_TIMEOUT
         endpoint = self._endpoint_creator.create_endpoint(
             service_model,
             endpoint_url,
             self._context.get_scoped_config(),
             self._response_parser_factory,
             tls_verification,
-            timeout,
+            (connect_timeout, read_timeout),
             self._retryhandler)
-        if Ed25519v1Auth.detect_private_key(credentials.private_key):
+        if AccessTokenAuth.is_access_token(credentials.access_token):
+            auth_method = AccessTokenAuth.AUTH_METHOD_NAME
+        elif Ed25519v1Auth.detect_private_key(credentials.private_key):
             auth_method = Ed25519v1Auth.AUTH_METHOD_NAME
         else:
             auth_method = RSAv1Auth.AUTH_METHOD_NAME
@@ -477,7 +492,7 @@ class Context(object):
         """
         self._context_instance_vars[logical_name] = value
 
-    def get_credentials(self):
+    def get_credentials(self, parsed_globals=None):
         """
         Return the :class:`botocore.credential.Credential` object
         associated with this session.  If the credentials have not
@@ -487,5 +502,6 @@ class Context(object):
 
         """
         if self._credentials is None:
-            resolver = credentials.create_credential_resolver(self)
-            return resolver.load_credentials()
+            resolver = credentials.create_credential_resolver(self, parsed_globals)
+            self._credentials = resolver.load_credentials()
+        return self._credentials
